<?php

page_open(array("sess" => "AG_Session",
		"auth" => "AG_Default_Auth"));

$sess->register("room");
$sess->register("onetime_password");

require("ag_page.inc");
require("ag_moo.inc");
require("browser.inc");

ag_page_init();


#
# Here's the meat of it.
#
# We keep the following state in the session.
#
# $room:        Current room id
#
# We should think about how to do presence stuff, but I'm
# going to defer this in order to get things up and running.
#

#
# Room motion
#

if ($moveto)
{
    #
    # Make sure this is a valid room
    #

    if (!ag_room_is_valid($moveto))
    {
	$room = "";
    }
    else
    {
	global $PHP_SELF;

    #
    # Check to see if we are allowed in this room. (LATER)
    #

	$room = $moveto;

	#
	# Bounce with a location header in order to
	# clear the ?moveto= from the URL.
	#
	header("Location: $PHP_SELF");
	page_close();
	return;
    }
    
}

#
# Okay, check out the room. If it isn't actually a room, or if it is not
# set, set back to the default room.
#

$room = ag_get_valid_room($room);

#
# Get the room info from the database
#

$db->query(sprintf("select name, description from room where id = %d",
		       $room));
if ($db->next_record())
{
    $name = $db->f("name");
    $desc = $db->f("description");
}

#
# Load up the room-view template
#

$templ = ag_load_page_template("room.i.html");

$templ->set_var("room", $name);
$templ->set_var("descr", $desc);

#
# Set up the admin options.
#

$admin_options = "";

#
# If we are allowed to edit this room, add the room-edit link.
#

if (ag_user_can_edit($auth->is_authenticated(), $room))
{
    $admin_options .= "<tr><td><a href=\"edit_room.php\">Edit this room</a></td></tr>\n";
}

if ($auth->is_authenticated())
{
    $admin_options .= "<tr><td><a href=\"cal.php\">Make a booking</a></td></tr>\n";
}

#
# If were a site admin, add the add-a-room link.
#



if (ag_user_is_site_admin($auth->is_authenticated()))
{
    $admin_options .= "<tr><td><a href=\"create_room.php\">Create a new room</a></td></tr>\n";
}

if ($admin_options != "")
{
    $admin_options = "<tr ><td><hr></td></tr>" . $admin_options;
}
$templ->set_var("admin_options", $admin_options);


#
# Basic stuff in place.
#
# Now cope with the objects in the room (channels),
# and the room exits.
#



#
# First the channels
#
# If the client is IE, we will use a bit of VBScript to
# cause the client to invoke the two urls that will deliver
# the custom content: room-sdp.php and room-mud.php.
#
# We only emit channels if the user is authenticated.
#



$uid = $auth->is_authenticated();


if ($uid && $uid != "nobody")
{
    $sdp_url = "room-sdp.php";
    $mud_url = "room-mud.php";

    $url_list = array($sdp_url, $mud_url);
    #$url_list = array($mud_url);

    #
    # If the client is IE, use vbscript. Otherwise use javascript.
#
    if (browser_is_ie() && 0)
    {
	$launch = ag_launch_vbscript($url_list);
    }
    else
    {
	$launch = ag_launch_javascript($url_list);
    }
}
else
{
    $launch = "";
}

$templ->set_var("channels", $launch);

$exitform .= "";
#
# The bookings
#

# get currently active bookings and index array by room id

$active_start=array();
$active_duration=array();
$active_desc=array();
$db->query(sprintf("select room_id, start_time, duration, description from booking where ( start_time <= now() and start_time + duration > now())"));
while ($db->next_record())
{
    $aroom = $db->f("room_id");
    $active_start[$aroom] = $db->f("start_time");
    $active_duration[$aroom] = $db->f("duration");
    $active_desc[$aroom] = $db->f("description");
}




  $d = getdate(time());
  $year = $d["year"];
  $month = $d["mon"];
  $day = $d["mday"];


$db->query(sprintf("set DateStyle = 'Postgres'; select start_time, duration, description from booking where ( room_id = %d and start_time >= '%s-%s-%s 00:00:00' and start_time < '%s-%s-%s 23:59:59' ) or ( start_time < '%s-%s-%s 00:00:00' and start_time + duration > '%s-%s-%s 00:00:00')",$room,$year,$month,$day,$year,$month,$day,$year,$month,$day,$year,$month,$day));
# $db->query("select start_time, duration, description from booking where room_id = $room");
$done_header=0;
while ($db->next_record())
{

   if( $done_header == 0 ){
     $done_header=1;
     $exitform .=  "<p><b>Todays Bookings:</b><p>\n<table border=\"1\">\n";
     $exitform .=  "<tr><th>Start time</th><th>Duration</th><th>Description</th></tr>\n";
    }
    $start_time = $db->f("start_time");
    $duration = $db->f("duration");
    $desc = $db->f("description");
    if( $start_time == $active_start[$room] ){
      $exitform .= "<tr><td><b>$start_time</b></td><td><b>$duration</b></td><td><b>$desc</b></td></tr></b>\n";
    }else{
      $exitform .= "<tr><td>$start_time</td><td>$duration</td><td>$desc</td></tr>\n";
    }
}
if( $done_header == 1){
$exitform .= "</table>\n";
}

#
# Now the exits
#

$exits = ag_get_room_exits($room);

$exitform .=  "<p><b>Exits:</b><p>\n<ul>\n";
foreach ($exits as $exit)
{
    $name = $exit[1];
    $num= $exit[0];
    $exitform .= "<li><a href=\"$PHP_SELF?moveto=$num\">$name</a>";
    if( $active_desc[$num] != "" ){
      $exitform .= "<p>Currently booked: <table border=\"1\">";
     $exitform .=  "<tr><th>Start time</th><th>Duration</th><th>Description</th></tr>\n<tr><td>";
      $exitform .= $active_start[$num];
      $exitform .= "</td><td>";
      $exitform .= $active_duration[$num];
      $exitform .= "</td><td>";
      $exitform .= $active_desc[$num];
      $exitform .= "</td></tr></table>";
    }
    $exitform .= "\n";
    
}


#
# The remote exits.
#

$db->query("select name, remote_link from remote_exit where room_id = $room");
while ($db->next_record())
{
    $link = $db->f("remote_link");
    $name = $db->f("name");
    $link = stripslashes($link);
    $name = stripslashes($name);
    $exitform .= "<li><a href=\"$link\">$name</a>\n";
}

$exitform .= "</ul>\n";

$templ->set_var("contents", $exitform);

#
# Set the onetime mud password. This will get picked up by the
# room-mud and/or room-sdp pages. We set the value here so that
# if we are using *both* room-mud and room-sdp they both have the
# same value.
# 

$uid = $auth->is_authenticated();

if ($uid && $uid != "nobody")
{
    $db->query("select mud_character from mud_char where user_id = $uid");
    if ($db->next_record())
    {
	$user_mud_id = $db->f("mud_character");
	$onetime_password = ag_moo_random_password();
	ag_moo_set_onetime_password($user_mud_id, crypt($onetime_password));
    }
}

ag_page_done($templ);

page_close();

?>
